@@ -8,9 +8,9 @@ from .utils import get_public_schema_name
 
 
 class TenantMixin(models.Model):
-    auto_create_schema = True # set this flag to false on a parent class if
-                              # you dont want the schema to be automatically
-                              # created upon save.
+    auto_create_schema = True  # set this flag to false on a parent class if
+                               # you dont want the schema to be automatically
+                               # created upon save.
 
     domain_url = models.CharField(max_length=128, unique=True)
     schema_name = models.CharField(max_length=63)
@@ -18,9 +18,10 @@ class TenantMixin(models.Model):
     class Meta:
         abstract = True
 
-    def save(self, verbosity = 1, *args, **kwargs):
+    def save(self, verbosity=1, *args, **kwargs):
         if connection.get_schema() != get_public_schema_name():
-            raise Exception("Can't update tenant outside the public schema. Current schema is %s." % connection.get_schema())
+            raise Exception("Can't update tenant outside the public schema. Current schema is %s."
+                            % connection.get_schema())
 
         is_new = self.pk is None
         super(TenantMixin, self).save(*args, **kwargs)
@@ -31,7 +32,7 @@ class TenantMixin(models.Model):
 
         transaction.commit_unless_managed()
 
-    def create_schema(self, check_if_exists = False, sync_schema = True, verbosity = 1):
+    def create_schema(self, check_if_exists=False, sync_schema=True, verbosity=1):
         """
         Creates the schema 'schema_name' for this tenant. Optionally checks if the schema
         already exists before creating it. Returns true if the schema was created, false
@@ -56,7 +57,7 @@ class TenantMixin(models.Model):
                          interactive=False,  # don't ask to create an admin user
                          migrate_all=True,  # migrate all apps directly to last version
                          verbosity=verbosity,
-            )
+                         )
 
             # fake all migrations
             if 'south' in settings.INSTALLED_APPS and not django_is_in_test_mode():
