@@ -1,6 +1,7 @@
 from django.db import models
 from tenant_schemas.models import TenantMixin
 
+
 # as TenantMixin is an abstract model, it needs to be created
 class Tenant(TenantMixin):
     pass
@@ -15,6 +16,7 @@ class NonAutoSyncTenant(TenantMixin):
     class Meta:
         app_label = 'tenant_schemas'
 
+
 class DummyModel(models.Model):
     """
     Just a test model so we can test manipulating data
@@ -22,5 +24,8 @@ class DummyModel(models.Model):
     """
     name = models.CharField(max_length=1337) # every dummy should have a pretty name :)
 
+    def __unicode__(self):
+        return self.name
+
     class Meta:
         app_label = 'tenant_schemas'
\ No newline at end of file
